@@ -46,6 +46,9 @@
 #define GOK_GCONF_RESOURCE_DIRECTORY       "/apps/gok/resource_directory"
 #define GOK_GCONF_PREFS_LOCKED             "/apps/gok/prefs_locked"
 
+#define GOK_GCONF_SPY_SEARCH_DEPTH         "/apps/gok/spy/gui_search_depth"
+#define GOK_GCONF_SPY_SEARCH_BREADTH       "/apps/gok/spy/gui_search_breadth"
+
 #define GOK_GCONF_ACCESS_METHOD_SETTINGS   "/apps/gok/access_method_settings"
 #define GOK_GCONF_ACCESS_METHOD_SETTINGS_WORKAROUND "/apps/gok/access_method_settings/workaround"
 
