@@ -1275,16 +1275,16 @@ gok_key_status_image (GokKey *key)
 
 #if STATUS_IMAGES
 	if (state.latched) {
-		icon_name = "gok/latched.png";
+		icon_name = "latched.png";
 	}
 	else if (state.locked) {
-		icon_name = "gok/locked.png";
+		icon_name = "locked.png";
 	}
 	else {
-		icon_name = "gok/empty.png";
+		icon_name = "empty.png";
 	}
 #else
-	icon_name = "gok/small-empty.png";
+	icon_name = "small-empty.png";
 #endif
 	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
 					  icon_name,
@@ -1318,7 +1318,7 @@ gok_key_create_image_widget (GokKey* pKey)
 			break;
 		case IMAGE_TYPE_STOCK:
 			image = gtk_image_new_from_stock (pKey->pImage->Filename,
-							  pKey->pImage->stock_size);
+							  GTK_ICON_SIZE_BUTTON /*pKey->pImage->stock_size*/);
 			break;
 		case IMAGE_TYPE_FIXED:
 		default:
@@ -2108,6 +2108,7 @@ gok_keyimage_new (GokKey* pKey, gchar* pFilename)
 	GokKeyImage* pNewImage;
 	GokKeyImage* pKeyImage;
 
+	gok_log_enter();
 	pNewImage = (GokKeyImage*) g_malloc (sizeof (GokKeyImage));
 
 	pNewImage->Filename = NULL;
@@ -2139,6 +2140,7 @@ gok_keyimage_new (GokKey* pKey, gchar* pFilename)
 		pKey->has_image = TRUE;
 	}
 	
+	gok_log_leave();
 	return pNewImage;
 }
 	 
