@@ -143,8 +143,8 @@ int gok_wordcomplete_predict (const gunichar letter)
 	gint count;
 	gint length;
 	gint statusPrediction = 0;
-	gchar* pWordsPredicted;
-	gchar* token;
+	gchar* pWordsPredicted = NULL;
+	gchar* token = NULL;
 	gchar separators[] = " ,\t\n";
 
 	/* is word completion turned on? */
@@ -226,7 +226,8 @@ int gok_wordcomplete_predict (const gunichar letter)
 	/* fill in the word completion keys */
 	count = 0;
 	pKey = pKeyboard->pKeyFirst;
-	token = strtok (pWordsPredicted, separators);
+	if (pWordsPredicted)
+		token = strtok (pWordsPredicted, separators);
 	while (token != NULL)
 	{
 		/* make sure we're not going over our maximum predictions */
